@@ -2,9 +2,9 @@ package controller
 
 import (
 	"io"
-	"regexp"
 
 	"github.com/spf13/afero"
+	"github.com/suzuki-shunsuke/tfmv/pkg/types"
 )
 
 type Controller struct {
@@ -13,35 +13,22 @@ type Controller struct {
 	stderr io.Writer
 }
 
+// Init initializes the Controller.
 func (c *Controller) Init(fs afero.Fs, stdout, stderr io.Writer) {
 	c.fs = fs
 	c.stdout = stdout
 	c.stderr = stderr
 }
 
-type Input struct {
-	File      string
-	Dest      string
-	Replace   string
-	Regexp    string
-	Include   *regexp.Regexp
-	Exclude   *regexp.Regexp
-	Args      []string
-	Recursive bool
-	DryRun    bool
-}
-
-type Dir struct {
-	Path   string
-	Files  []string
-	Blocks []*Block
-}
-
+// Summary represents a summary of changes.
+// It is used to output a summary of changes.
 type Summary struct {
+	// Changes is a list of changes.
 	Changes []*Change `json:"changes"`
 }
 
-func (s *Summary) FromDirs(dirs map[string]*Dir) {
+// FromDirs updates the Summary from a list of directories.
+func (s *Summary) FromDirs(dirs map[string]*types.Dir) {
 	s.Changes = []*Change{}
 	for _, dir := range dirs {
 		for _, block := range dir.Blocks {
@@ -54,8 +41,12 @@ func (s *Summary) FromDirs(dirs map[string]*Dir) {
 	}
 }
 
+// Change represents a change of a Terraform block.
 type Change struct {
-	Dir        string `json:"dir"`
-	Address    string `json:"address"`
+	// Dir is a Terraform module directory path.
+	Dir string `json:"dir"`
+	// Address is a current Terraform address.
+	Address string `json:"address"`
+	// NewAddress is a new Terraform address.
 	NewAddress string `json:"new_address"`
 }
